<?php
/* vim: set et ts=4 sw=4 sts=4 ai: */
// +----------------------------------------------------------------------+
// | Site-wide configuration                                              |
// +----------------------------------------------------------------------+
// | @version $Revision: 1.16 $
// +----------------------------------------------------------------------+
//
// The first 3 parameters have to be changed: DB, TRIPCODE_SECRET, and
// ADMINS.

// Data Source Name. As as ochiba v0.9.3, PEAR::DB is used for database
// abstraction. For detailed information on the DSN, please see:
//  <http://pear.php.net/manual/en/package.database.db.intro-dsn.php>
//
// Though PEAR::DB provides abstraction for many databases, ochiba has 
// only been tested with SQLite, PostgreSQL, and MySQL. Where applicable,
// the Postgres type is considered "default", but compatiblity with
// other databases is not insured (in fact, it's probably not likely)
//
// Examples (make sure to set one of these!):
#define("DB","sqlite:////path/to/sqlite/database/file");
#define("DB","pgsql://user:pass@unix(/tmp)/dbname");
#define("DB","pgsql://user:pass@hostname/dbname");
#define("DB","mysql://user:pass@unix(/var/lib/mysql/mysql.sock)/dbname");
#define("DB","mysql://user:pass@hostname/dbname");

// Site-specific tripcode generation. You never have to type this anywhere
// so make it really really long.
define("TRIPCODE_SECRET","changeme");

//----- Special people
//      ADMINS can create new categories and re-order pictures
//      MODERATORS can delete images and manage bans
//      They are separate; someone who needs to do both should be placed
//      in both lists (comma-separated tripcodes). Or, if it's just one
//      person, you can define the tripcode in ADMINS and just define
//      MODERATORS, FEATURE_THROTTLE_EXCEPTIONS, FEATURE_ZIP_UPLOADERS, etc
//      as ADMINS
define("ADMINS",'changeme');
define("MODERATORS",ADMINS);

//----- General settings
// Default text for the <title> tag
define("HTML_TITLE","ochiba");
// How long the name/tripcode cookies are good for, in seconds
// This is reset with every post, so it doesn't have to be too long
define("COOKIE_EXPIRES",time()+2592000);

// Number of threads per page. This also determines number of entries
// on the special "stats" page
define("LIMIT",10);

// Size of the pager (number of pages directly linked on the pager)
define("PAGER_SIZE",10);

// Date format; this is fed into PHP date() (see http://www.php.net/date)
define("DATE_FORMAT","Y-m-d H:i:s T");

//----- Features
define("FEATURE_CACHE",true);		// Enable caching of pages?
define("FEATURE_CACHE_REFRESH",60);	// Minutes a cache is good for
define("FEATURE_VERIFY",true);		// Enable verification?
define("FEATURE_SHOWALL",true);	    // Enable "All" image subsection?
define("FEATURE_STATS",true);		// Enable stats page?
define("FEATURE_STATS_POPULAR",25); // How many most popular keywords to show
define("FEATURE_RSS",true);			// Enable RSS feed?
define("FEATURE_FETCH",false);		// Enable URL fetch instead of upload?
define("FEATURE_SAGE",20);		    // Number of replies before no longer bumped, or false
define("FEATURE_MULTIPLE_CATEGORY",true);   // Allow multiple categories per post?

// Restrict posting? If so, only tripcodes provided in a comma-separated list will
// be allowed to post. This is for self- (or group-) managed image collections.
// This only applies to image posts - comments are always allowed.
//
// Set to false if you want unrestricted posting
define("FEATURE_RESTRICT_POSTING",false);

// Enable posting throttle? If FEATURE_THROTTLE is true, then an IP *SUBNET*
// will only be allowed to post NUMBER per PERIOD minutes. This will apply to
// image posts and to comment posts.
//
// A small roadblock to flooding...
//
// Users with tripcodes listed in FEATURE_THROTTLE_EXCEPTIONS are not
// subject to the throttle (comma-seperated list)
define("FEATURE_THROTTLE",true);		// Enable posting throttle? See next two:
define("FEATURE_THROTTLE_NUMBER",20);	// HOW MANY
define("FEATURE_THROTTLE_PERIOD",60);	// MINUTES
define("FEATURE_THROTTLE_EXCEPTIONS",ADMINS);

// Zip uploading? Tripcodes listed here will accept a zip file upload; the
// zip will be uncompressed and any files enclosed will be processed in bulk.
// Obviously, a dangerous feature in the wrong hands. Also keep in mind that
// PHP has built-in limits on the size of a POST - see the post_max_size and
// upload_max_filesize options in php.ini.
define("FEATURE_ZIP_UPLOADERS",ADMINS);

// Alternate way to allow multiple file uploads: allow user to request multiple
// file inputs. Set this to the number of files per post allowed, or false to only
// allow 1 file per post
define("FEATURE_MULTIPLE_UPLOAD",false);

// Thread truncation. This will show only the 1st, then the last X number
// if activated (in other words, show only the newest X replies to a thread)
// Set to false if you want to disable
define("FEATURE_THREAD_TRUNCATE",10);

// Count views? This has serious performance ramifications; if you have
// performance concerns, you should turn this off.
define("FEATURE_COUNT_VIEWS",true);
// Cache image views? This only applies when the above is on. This can save
// bandwidth. Set to false, or to a integer number of days. Note this will mess
// with the view counting above.
define("FEATURE_CACHE_VIEWS",10);

//----- Image processing stuff
// ie convert "-geometry x" "old" "new"
// Note that the MAXIMUM_SIZE is overridden by PHP parameters (see post_max_size
// and upload_max_filesize in php.ini)
define("CONVERT","/usr/bin/convert -quality 90 -geometry %s %s[0] %s 2>&1");
define("IDENTIFY","/usr/bin/identify");
define("THUMB_SIZE",150);					// Max thumb dimension, longest side
define("SUBTHUMB_SIZE",100);				// Max subthumb dimension, longest side
define("MAXIMUM_SIZE",2000000);				// bytes

//----- Directories.
// This is all self-discovery; only change if you specifically want to put 
// stuff other than at their default locations.
$script_dir = dirname($_SERVER["SCRIPT_NAME"]);
define("ROOT",$script_dir=="/" ? "" : $script_dir);
define("ABSOLUTE_ROOT","http://${_SERVER["HTTP_HOST"]}" . ROOT);
define("IMAGE_DIR",dirname(__FILE__) . "/img");
define("THUMB_DIR",dirname(__FILE__) . "/thumbs");
define("TEMPLATE_DIR",dirname(__FILE__) . "/templates");
define("CACHE_DIR","/tmp/ochiba-cache"); // See FEATURE_CACHE
define("IMAGE_URL",ROOT . "/img");
define("THUMB_URL",ROOT . "/thumbs");
define("TMP_DIR","/tmp");
define("INCLUDES_DIR","includes");
define("DELETED_IMAGE","deleted.gif");

// For wget-based URL fetches. The first is a sprintf string. The second is
// The user-agent string to use, because some sites reject wget. Bleah.
define("WGET",'/usr/bin/wget -q --user-agent="%s" --referer="%s" -O "%s" "%s" 2>&1 >/dev/null');
define("WGET_USER_AGENT","Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.6) Gecko/20040124 Galeon/1.3.14");

// JS snippet to auto-close windows
define("JS_AUTO_CLOSE",'<script type="text/javascript">popoff(true)</script>');
// CSS include for popups (hide stuff)
define("POPUP_CSS",'<link rel="stylesheet" type="text/css" href="'.ROOT.'/css/popup.css" />');

// Stupid way of localizing
include_once(INCLUDES_DIR . "/strings.php");

// Make sure the tripcode secret was set
if(TRIPCODE_SECRET=="changeme") {
	echo "You must set a tripcode secret in " . __FILE__;
	exit;
}
?>
